from setuptools import setup

setup(name='marlindb',
      version='0.1.0.3',
      description='Python interface for MarlinDB',
      url='http://www.datainz.com',
      author='DataInz Technologies Pvt. Ltd.',
      author_email='johnspaul92@gmail.com',
      license='Proprietary License',
      packages=['marlindb'],
      zip_safe=False)
